@@ -5,7 +5,7 @@
    eMail: wsp@gmx.de
 
 Created: 1999/06/05
-Updated: 2001/06/24
+Updated: 2001/08/05
 */
 
 /* Copying:
@@ -221,7 +221,6 @@ int cddb_local_lookup(char *path, char **cddb_fn)
     if(fs_new == NULL) fs_new = fs_anchor;
   } else fs_new = fs_anchor;
 
-  /* We need filename!!!!! check this!!!!! */
   local_filename = (char *) malloc(sizeof(char) * (strlen(fs_new->
 							  information)+1));
   if(local_filename == NULL) {
@@ -399,7 +398,9 @@ int cddb_open_cddbp(char *addr)
   fprintf(stderr, "DEBUG: answered: \"%s\"\n", buf);
 #endif
   if(buf[0] != '2') {
-    print_stat_win(buf);
+    tmp_str = strchr(buf, '\n');
+    if(tmp_str) *tmp_str = 0;
+    popup_error_win(buf);
     free(buf);
     close(cddb_fd);
     return -1;
