@@ -1,11 +1,11 @@
 /* save and transmit cddb-information
 
    Written by Matthias Hensler
-   Copyright WSPse 1999+2000
-   eMail: wsp@gmx.de
+   Copyright WSPse 1999-2001
+   eMail: mh@wspse.de
 
 Created: 2000/02/28
-Updated: 2000/03/20
+Updated: 2001/07/23
 */
 
 /* Copying:
@@ -643,9 +643,9 @@ int cddb_remote_transfer_entry(char *filename, char *subject, char *smtp_serv,
   }
 
   if(tmp) {
-    sprintf(buf, "EHLO %s\n", tmp);
+    sprintf(buf, "EHLO %s\r\n", tmp);
   } else {
-    strcpy(buf, "EHLO localhost\n");
+    strcpy(buf, "EHLO localhost\r\n");
   }
   
   print_stat_win(_("saying hello to SMTP-server"));
@@ -669,7 +669,7 @@ int cddb_remote_transfer_entry(char *filename, char *subject, char *smtp_serv,
   if(! buf) {
     wuuush(1);
   }
-  sprintf(buf, "MAIL FROM: <%s>\n", from);
+  sprintf(buf, "MAIL FROM: <%s>\r\n", from);
   print_stat_win(_("submitting from address"));
 
   if(write_to_sock(buf, strlen(buf), smtp_fd) != 0) {
@@ -697,7 +697,7 @@ int cddb_remote_transfer_entry(char *filename, char *subject, char *smtp_serv,
     }
     sprintf(buf, "RCPT TO: <%s>", rcpt[j]);
     print_stat_win(buf);
-    strcat(buf, "\n");
+    strcat(buf, "\r\n");
 
     if(write_to_sock(buf, strlen(buf), smtp_fd) != 0) {
       popup_error_win(_("RCPT TO failed"));
@@ -721,7 +721,7 @@ int cddb_remote_transfer_entry(char *filename, char *subject, char *smtp_serv,
   }
   
   print_stat_win(_("preparing data transfer"));
-  if(write_to_sock("DATA\n", 5, smtp_fd) != 0) {
+  if(write_to_sock("DATA\r\n", 5, smtp_fd) != 0) {
     popup_error_win(_("SMTP: DATA cmd failed"));
     close(smtp_fd);
     return 1;
@@ -740,11 +740,11 @@ int cddb_remote_transfer_entry(char *filename, char *subject, char *smtp_serv,
     wuuush(1);
   }
 
-  sprintf(buf, "From: %s\n"
-	  "Reply-To: %s\n"
-	  "To: %s\n"
-	  "Subject: %s\n"
-	  "\n\n", from, from, rcpt_list, subject);
+  sprintf(buf, "From: %s\r\n"
+	  "Reply-To: %s\r\n"
+	  "To: %s\r\n"
+	  "Subject: %s\r\n"
+	  "\r\n\r\n", from, from, rcpt_list, subject);
 
   if(write_to_sock(buf, strlen(buf), smtp_fd) != 0) {
     popup_error_win(_("SMTP: sending header failed"));
@@ -762,11 +762,17 @@ int cddb_remote_transfer_entry(char *filename, char *subject, char *smtp_serv,
   }
 
   while(1) {
-    fgets(buffer, SMTP_MAXLEN-1, mail);
+    fgets(buffer, SMTP_MAXLEN-2, mail);
     if(feof(mail)) break;
     if(strcmp(buffer, ".\n") == 0) {
-      i = write_to_sock(". \n", 3, smtp_fd);
+      i = write_to_sock(". \r\n", 3, smtp_fd);
     } else {
+      if(strlen(buffer) && buffer[strlen(buffer)-1] == '\n') {
+	i = strlen(buffer);
+	buffer[i-1] = '\r';
+	buffer[i]   = '\n';
+	buffer[i+1] = 0;
+      }
       i = write_to_sock(buffer, strlen(buffer), smtp_fd);
     }
     if(i) {
@@ -778,7 +784,7 @@ int cddb_remote_transfer_entry(char *filename, char *subject, char *smtp_serv,
 
   fclose(mail);
 
-  if(write_to_sock(".\n", 2, smtp_fd)) {
+  if(write_to_sock(".\r\n", 2, smtp_fd)) {
     popup_error_win(_("SMTP: mail closing timeout"));
     close(smtp_fd);
     return 1;
@@ -789,7 +795,7 @@ int cddb_remote_transfer_entry(char *filename, char *subject, char *smtp_serv,
     popup_error_win(_("error delivering mail"));
     j = 1;
   } else {
-    write_to_sock("QUIT\n", 5, smtp_fd);
+    write_to_sock("QUIT\r\n", 5, smtp_fd);
     j = 0;
   }
 
