@@ -1,11 +1,11 @@
 /* files and filehandling
 
    Written by Matthias Hensler
-   Copyright WSPse 1999-2001
-   eMail: wsp@gmx.de
+   Copyright WSPse 1999-2004
+   eMail: matthias@wspse.de
 
 Created: 1999/06/12
-Updated: 2001/06/27
+Updated: 2004/04/15
 */
 
 /* Copying:
@@ -50,10 +50,11 @@ extern void popup_error_win(char *tx);
 extern char *copy_char_str(char *old);
 extern BOOL fn_toupper;
 extern int  fn_mode;
+extern char replace_space_ch;
 extern char *fn_pattern;
 extern char *fn_pattern_mix;
 extern char *mp3_genre[];
-extern char config_fancy_colors;
+extern signed char config_fancy_colors;
 extern char *def_cddb_server;
 extern char *def_cddb_bank;
 extern char *def_cdrom_dev;
@@ -173,8 +174,8 @@ char *filenm_short(char *file_name, int mode, BOOL toup, char *protect_mask)
 	/* space detected, look what we must do now */
 	was_space = TRUE;      /* next character can converted to upper (if flag is set) */
 	if(mode == 0)      *(ret_name + (j++)) = ' ';   /* space allowed                 */
-	else if((mode == 1) && (! uscr_inserted)) {     /* insert max one underscore     */
-	  *(ret_name + (j++)) = '_';   /* convert to underscore */
+	else if((mode == 1) && (!uscr_inserted)) {      /* insert max one underscore     */
+	  *(ret_name + (j++)) = replace_space_ch;       /* convert to underscore */
 	  uscr_inserted = TRUE;
 	}
       } else if(strchr(def_ill_chars, *(file_name+i))) {
@@ -206,7 +207,6 @@ char *filenm_short(char *file_name, int mode, BOOL toup, char *protect_mask)
   }
  
   *(ret_name+j) = 0;
-//  fprintf(stderr, "\n\r%s\n\r", ret_name);
 
   if(strlen(ret_name) != strlen(file_name)) {
     /* size has changed, free unused memory */
@@ -257,7 +257,11 @@ void filenm_generate(song_typ *track)
       perror("malloc");
       wuuush(1);
     }
+#ifdef OGG_AS_DEFAULT
+    snprintf(fn_new, 30, "unknown-%02d_%08lX.ogg", (track->toc)+1, track->cddb_id);
+#else
     snprintf(fn_new, 30, "unknown-%02d_%08lX.mp3", (track->toc)+1, track->cddb_id);
+#endif
     track->filename = kill_double_slashs(fn_new);
     return;
   }
@@ -444,14 +448,14 @@ int save_config(char *fn)
   fputs("\n# if remote CDDB access is allowed\n", conf_fd);
   fprintf(conf_fd, "rem_cddb = %d\n", config_cddb_enbl);
 
-  fputs("\n# mailadress to which CDDB should be sent (more addresses maybe seperated\n"
+  fputs("\n# mailaddress to which CDDB should be sent (more addresses maybe seperated\n"
 	"# by commas)\n", conf_fd);
   fprintf(conf_fd, "cddb_email = \"%s\"\n", def_cddb_email);
 
   fputs("\n# relaying smtp-server who handle my emails [host:port]\n", conf_fd);
   fprintf(conf_fd, "smtp_serv = \"%s\"\n", def_smtp_server);
 
-  fputs("\n# my email adress for authorizing [user@host]\n", conf_fd);
+  fputs("\n# my email address for authorizing [user@host]\n", conf_fd);
   fprintf(conf_fd, "my_email = \"%s\"\n", def_my_email);
 
   fputs("\n# directory for mp3-files\n", conf_fd);
@@ -553,9 +557,10 @@ int save_config(char *fn)
   fprintf(conf_fd, "mp3_pattern_mix = \"%s\"\n", fn_pattern_mix);
 
   fputs("\n# mode for handling spaces in filenames\n"
-	"#  0: spaces allowed, 1: spaces will be converted to underscores\n"
+	"#  0: spaces allowed, 1: spaces will be converted to specified replace character\n"
 	"#  2: spaces will be killed\n", conf_fd);
   fprintf(conf_fd, "pat_mode = %d\n", fn_mode);
+  fprintf(conf_fd, "space_rep_char = \"%c\"\n", replace_space_ch);
 
   fputs("\n# appereance of filename case\n"
 	"#  0: as it is in CDDB entry\n"
@@ -846,6 +851,13 @@ int load_config(char *fn)
 	    fn_mode = 1;
 	    usleep(500000);
 	  }
+	} else if(strcmp(key, "space_rep_char") == 0) {
+	  replace_space_ch = *arg;
+	  if(strlen(arg) == 0) replace_space_ch = '_';
+	  else if(strlen(arg) > 1) {
+	    print_stat_win(_("more than one character in \"space_rep_char\", skipping trailing garbage"));
+	    usleep(500000);
+	  }
 	} else if(strcmp(key, "case_chg") == 0) {
 	  config_case_chg = atoi(arg);
 	  if(config_case_chg < 0 || config_case_chg > 2) {
@@ -900,7 +912,7 @@ int load_config(char *fn)
 	  }
 	} else if(strcmp(key, "auto_save") == 0) {
 	  auto_save = atoi(arg);
-	  if(auto_save != 0) auto_save = 1;
+	  if(auto_save != 1) auto_save = 0;
 	} else if(strcmp(key, "use_dir_request") == 0) {
 	  config_curs_dir = atoi(arg);
 	  if(config_curs_dir != FALSE) config_curs_dir = TRUE;
@@ -1101,7 +1113,11 @@ char *build_mp3_filenm(song_typ *track)
       perror("malloc");
       wuuush(1);
     }
+#ifdef OGG_AS_DEFAULT
+    sprintf(extnl_MP3_name, "track-%d.ogg", (track->toc)+1);
+#else
     sprintf(extnl_MP3_name, "track-%d.mp3", (track->toc)+1);
+#endif
     return (kill_double_slashs(extnl_MP3_name));
   }
   
