@@ -2,11 +2,11 @@
    show helpscreen
 
    Written by Matthias Hensler
-   Copyright WSPse 1999-2001
-   eMail: wsp@gmx.de
+   Copyright WSPse 1999-2004
+   eMail: matthias@wspse.de
 
 Created: 1999/06/13
-Updated: 2001/06/27
+Updated: 2004/04/15, MH: fixed non ASCII characters
 */
 
 /* Copying:
@@ -374,7 +374,7 @@ void pop_up_info()
   info_text = is_build_array(temp_buf, &len);
   free(temp_buf);
 
-  is_popup_text((const char **) info_text, 45, len+2);
+  is_popup_text((const char **) info_text, 65, len+2);
 
   /* free info-text array */
   free_char_array(info_text);
@@ -409,7 +409,7 @@ void pop_up_help()
 	  "F9: Delete actual track\n"
 	  "\n"
 	  "Note for F-keys:\n"
-	  "Since F-keys wont work in all enviroments,\n"
+	  "Since F-keys won't work in all enviroments,\n"
 	  "you can use number-keys instead. Press '1'\n"
 	  "for F1, '2' for F2, and so on\n"
 	  "\n"
@@ -526,7 +526,7 @@ void pop_up_help()
 	  "spaces in filenames or not and you can input a list\n"
 	  "with all characters you don't like in filenames.   \n"
 	  "Each character which is killed is then replaced by \n"
-	  "an underscore \"_\" or left out. You can select what \n"
+	  "an defined char or left out. You can select what   \n"
 	  "you like by setting \"Patternmode\" in option-menu.  \n"
 	  "A nice additional feature is to convert characters \n"
 	  "toupper if the previous was killed. This is really \n"
@@ -599,7 +599,7 @@ void pop_up_help()
 	  "look on http://mp3c.wspse.de/\n"
 	  "for new versions\n"
 	  "\n"
-	  "WSPse 1999-2001")
+	  "WSPse 1999-2004")
 	  , &len);
   }
   
