@@ -1,11 +1,11 @@
 /* option operations
 
    Written by Matthias Hensler
-   Copyright WSPse 1999-2001
-   eMail: wsp@gmx.de
+   Copyright WSPse 1999-2004
+   eMail: matthias@wspse.de
 
 Created: 1999/06/06
-Updated: 2001/07/26
+Updated: 2004/04/25
 */
 
 /* Copying:
@@ -75,8 +75,9 @@ extern char     *fn_pattern_mix;
 extern char     *def_ill_chars;
 extern char     *def_exp_file;
 extern int      fn_mode;
+extern char     replace_space_ch;
 extern BOOL     fn_toupper;
-extern char     config_fancy_colors;
+extern signed char config_fancy_colors;
 extern int      of_fifo_buf;
 extern int      auto_save;
 extern char     *external_config_file;
@@ -203,11 +204,11 @@ void option_menu(WINDOW *win)
       
       add_field_entry(&anchor, _("CDDB server"), 2, def_cddb_server);
 
-      add_field_entry(&anchor, _("CDDB eMail adress"), 33, def_cddb_email);
+      add_field_entry(&anchor, _("CDDB eMail address"), 33, def_cddb_email);
 
       add_field_entry(&anchor, _("SMTP server"), 34, def_smtp_server);
 
-      add_field_entry(&anchor, _("My eMail adress"), 35, def_my_email);
+      add_field_entry(&anchor, _("My eMail address"), 35, def_my_email);
       
       add_field_entry(&anchor, _("local CDDB directory"), 3, def_cddb_bank);
 
@@ -218,15 +219,18 @@ void option_menu(WINDOW *win)
       }
       add_field_entry(&anchor, _("allow remote CDDB access?"), 30, mini_str);
       
-      add_field_entry(&anchor, _("MP3 destination directory"), 4, def_mp3_dir);
+      add_field_entry(&anchor, _("MP3/OGG destination directory"), 4, def_mp3_dir);
       
-      add_field_entry(&anchor, _("Pattern for mp3-filename creation"), 5, fn_pattern);
+      add_field_entry(&anchor, _("Pattern for mp3/ogg-filename creation"), 5, fn_pattern);
 
-      add_field_entry(&anchor, _("Pattern for mp3-filename (sampler cds)"), 39, fn_pattern_mix);
+      add_field_entry(&anchor, _("Pattern for mp3/ogg-filename (sampler cds)"), 39, fn_pattern_mix);
       
       sprintf(mini_str, "%d", fn_mode);
       add_field_entry(&anchor, _("Patternmode"), 6, mini_str);
 
+      sprintf(mini_str, "%c", replace_space_ch);
+      add_field_entry(&anchor, _("space replace character"), 42, mini_str);
+      
       if(config_case_chg == 0)      strcpy(mini_str, _("no"));
       else if(config_case_chg == 1) strcpy(mini_str, _("to lower"));
       else                          strcpy(mini_str, _("to upper"));
@@ -259,7 +263,7 @@ void option_menu(WINDOW *win)
       add_field_entry(&anchor, _("slash replace character"), 23, mini_str);
       
       if(eased_char_hand) {
-	strcpy(mini_str, _("non-strict (ISO 8859-1)"));
+	strcpy(mini_str, _("non-strict (8-bit Western)"));
       } else {
 	strcpy(mini_str, _("strict (7-bit ASCII)"));
       }
@@ -310,13 +314,13 @@ void option_menu(WINDOW *win)
       
       add_field_entry(&anchor, _("CDripper on-fly (output to stdout)"), 11, def_cd_rip_of);
       
-      add_field_entry(&anchor, _("MP3encoder non-fly (input from file)"), 12, def_mp3_enc_nf);
+      add_field_entry(&anchor, _("MP3/Oggencoder non-fly (input from file)"), 12, def_mp3_enc_nf);
       
-      add_field_entry(&anchor, _("MP3encoder on-fly (input from stdin)"), 13, def_mp3_enc_of);
+      add_field_entry(&anchor, _("MP3/Oggencoder on-fly (input from stdin)"), 13, def_mp3_enc_of);
       
-      add_field_entry(&anchor, _("Program for setting MP3-ID-fields"), 14, def_mp3_info);
+      add_field_entry(&anchor, _("Program for setting MP3/OGG-ID-fields"), 14, def_mp3_info);
       
-      add_field_entry(&anchor, _("MP3-comment"), 19, def_comment);
+      add_field_entry(&anchor, _("MP3/OGG-comment"), 19, def_comment);
 
       add_field_entry(&anchor, _("String for unknown genre"), 38, def_unknown_gen);
 
@@ -353,6 +357,9 @@ void option_menu(WINDOW *win)
       
       add_field_entry(&anchor, _("Load defaults"), 122, NULL);
       
+      add_field_entry(&anchor, _("Load Presets (OGG/oggenc)"), 123, NULL);
+      add_field_entry(&anchor, _("Load Presets (MP3/lame)"), 124, NULL);
+      
       add_field_entry(&anchor, _("Load Config"), 120, NULL);
       
       add_field_entry(&anchor, _("Save Config"), 121, NULL);
@@ -405,7 +412,7 @@ void option_menu(WINDOW *win)
 	break;
 
       case 4:
-	pointer = req_get_dir(def_mp3_dir, _("select MP3 destination directory"));
+	pointer = req_get_dir(def_mp3_dir, _("select MP3/OGG destination directory"));
 	if(pointer) {
 	  if(def_mp3_dir) free(def_mp3_dir);
 	  def_mp3_dir = pointer;
@@ -440,7 +447,7 @@ void option_menu(WINDOW *win)
 	sprintf(mini_str, "%d", fn_mode);
 	pointer = input_line2(16, mini_str, _("Enter pattern mode (0, 1 or 2)"),
 			      _("0: Spaces in filename allowed"),
-			      _("1: Spaces will be converted to \"_\" (underscores)"),
+			      _("1: Spaces will be converted to specified character"),
 			      _("2: every space will be killed"),
 			      NULL, NULL, NULL, TRUE);
 	if(pointer) {
@@ -528,7 +535,7 @@ void option_menu(WINDOW *win)
 	break;
 
       case 12:
-	pointer = input_line2(16, def_mp3_enc_nf, _("Program for encoding wav->mp3 (input from file)"),
+	pointer = input_line2(16, def_mp3_enc_nf, _("Program for encoding wav->mp3/ogg (input from file)"),
 			      _("%1: inputfile, %2: outputfile"),
 			      _("%3: album, %4: genre by number, %5: year"),
 			      _("%6: comment, %7: filename, %8: genre by name"),
@@ -544,7 +551,7 @@ void option_menu(WINDOW *win)
 	break;
 
       case 13:
-	pointer = input_line2(16, def_mp3_enc_of, _("Program for encoding wav->mp3 (input from stdin)"),
+	pointer = input_line2(16, def_mp3_enc_of, _("Program for encoding wav->mp3/ogg (input from stdin)"),
 			      _("%1: outputfile"),
 			      _("%3: album, %4: genre by number, %5: year"),
 			      _("%6: comment, %7: filename, %8: genre by name"),
@@ -560,7 +567,7 @@ void option_menu(WINDOW *win)
 	break;
 
       case 14:
-	pointer = input_line2(16, def_mp3_info, _("Program for setting MP3 ID-Fields (0 to disable)"),
+	pointer = input_line2(16, def_mp3_info, _("Program for setting MP3/OGG ID-Fields (0 to disable)"),
 			      _("%1: Artistname,  %2: Songtitle"),
 			      _("%3: Albumname"),
 			      _("%4: Genre (by number),  %8: Genre (by name)"),
@@ -625,7 +632,7 @@ void option_menu(WINDOW *win)
 	break;
 
       case 18:
-	if(select_yesno_box(_("use mp3-dir for playlists?"))) {
+	if(select_yesno_box(_("use mp3/ogg-dir for playlists?"))) {
 	  if(def_m3u_dir) free(def_m3u_dir);
 	  def_m3u_dir = (char *) malloc(sizeof(char) * 2);
 	  if(! def_m3u_dir) {
@@ -652,7 +659,7 @@ void option_menu(WINDOW *win)
 	break;
 
       case 19:
-	pointer = input_line2(16, def_comment, _("Enter pattern for mp3-comment"),
+	pointer = input_line2(16, def_comment, _("Enter pattern for mp3/ogg-comment"),
 			      _("%1: Artist, %2: Title, %3: Album, %4: Genre, %5: Year, %6: Track"),
 			      _("%7: Track (leading zeros), %8: MP3c-Version, %a: Encode-day"),
 			      _("%b: Encode-month, %c: Encode-year (2 digits), %d: Encode-year (4 dig)"),
@@ -704,7 +711,7 @@ void option_menu(WINDOW *win)
       case 22:
 	if(select_yesno_box(_("allow more characters in CDDB and inputbox?"))) {
 	  eased_char_hand = TRUE;
-	  strcpy(mini_str, _("non-strict (ISO 8859-1)"));
+	  strcpy(mini_str, _("non-strict (8-bit Western)"));
 	} else {
 	  eased_char_hand = FALSE;
 	  strcpy(mini_str, _("strict (7-bit ASCII)"));
@@ -872,7 +879,7 @@ void option_menu(WINDOW *win)
 	break;
 
       case 33:
-	pointer = input_line2(16, def_cddb_email, _("enter CDDBs eMail adress"),
+	pointer = input_line2(16, def_cddb_email, _("enter CDDBs eMail address"),
 			      _("you can input more servers, by seperating them with a comma"),
 			      NULL,
 			      _("at least \"freedb-submit@freedb.org\" should accept your entries"),
@@ -898,8 +905,8 @@ void option_menu(WINDOW *win)
 	break;
 
       case 35:
-	pointer = input_line2(16, def_my_email, _("enter your eMail adress"),
-			      _("please use the right adress, otherwise your SMTP-server"),
+	pointer = input_line2(16, def_my_email, _("enter your eMail address"),
+			      _("please use the right address, otherwise your SMTP-server"),
 			      _("might deny relaying."),
 			      NULL, NULL, NULL, NULL, TRUE);
 	if(pointer) {
@@ -980,6 +987,24 @@ void option_menu(WINDOW *win)
 	reb_filenm();
 	break;
 	
+      case 42:
+	sprintf(mini_str, "%c", replace_space_ch);
+	pointer = input_line(16, mini_str, _("character for replacing spaces"),
+			     TRUE);
+	if(pointer) {
+	  replace_space_ch = *pointer;
+	  if(strlen(pointer) < 1) replace_space_ch = '-';
+	  else if(strlen(pointer) > 1) {
+	    popup_error_win(_("too many chars, skipping trailing garbage"));
+	  }
+	  free(pointer);
+	  reb_filenm();
+	  check_config();
+	  sprintf(mini_str, "%c", replace_space_ch);
+	  reb_field_entry(new, NULL, mini_str);
+	}
+	break;
+	
       case 120:
 	get_config(external_config_file);
 	check_config();
@@ -1003,6 +1028,48 @@ void option_menu(WINDOW *win)
 	loaded_def = TRUE;
 	use_old    = FALSE;
 	break;
+
+      case 123:
+	/* load presets 1: OGG/oggenc */
+	if(fn_pattern)     free(fn_pattern);
+	if(fn_pattern_mix) free(fn_pattern_mix);
+	if(def_mp3_enc_nf) free(def_mp3_enc_nf);
+	if(def_mp3_enc_of) free(def_mp3_enc_of);
+	if(def_mp3_info)   free(def_mp3_info);
+
+	fn_pattern     = copy_char_str(PRE1_PATTERN);
+	fn_pattern_mix = copy_char_str(PRE1_PATTERN_M);
+	def_mp3_enc_nf = file_glob_in_name(copy_char_str(PRE1_ENC_NF));
+	def_mp3_enc_of = file_glob_in_name(copy_char_str(PRE1_ENC_OF));
+	def_mp3_info   = file_glob_in_name(copy_char_str(PRE1_ENC_INFO));
+	
+	check_config();
+	free_field_select(&anchor);
+	anchor     = NULL;
+	loaded_def = TRUE;
+	use_old    = FALSE;
+	break;
+
+      case 124:
+	/* load presets 2: MP3/lame */
+	if(fn_pattern)     free(fn_pattern);
+	if(fn_pattern_mix) free(fn_pattern_mix);
+	if(def_mp3_enc_nf) free(def_mp3_enc_nf);
+	if(def_mp3_enc_of) free(def_mp3_enc_of);
+	if(def_mp3_info)   free(def_mp3_info);
+
+	fn_pattern     = copy_char_str(PRE2_PATTERN);
+	fn_pattern_mix = copy_char_str(PRE2_PATTERN_M);
+	def_mp3_enc_nf = file_glob_in_name(copy_char_str(PRE2_ENC_NF));
+	def_mp3_enc_of = file_glob_in_name(copy_char_str(PRE2_ENC_OF));
+	def_mp3_info   = file_glob_in_name(copy_char_str(PRE2_ENC_INFO));
+	
+	check_config();
+	free_field_select(&anchor);
+	anchor     = NULL;
+	loaded_def = TRUE;
+	use_old    = FALSE;
+	break;
     }
   }
   
