@@ -1,11 +1,11 @@
 /* handling for child and subprocesses
 
    Written by Matthias Hensler
-   Copyright WSPse 1999+2000
-   eMail: wsp@gmx.de
+   Copyright WSPse 1999-2004
+   eMail: matthias@wspse.de
 
 Created: 1999/06/19
-Updated: 2000/07/26
+Updated: 2004/04/15, MH: fixed non ASCII characters
 */
 
 /* Copying:
@@ -71,7 +71,7 @@ extern BOOL select_yesno_box(char *tx);
 extern int create_sub_dirs(char *filename, BOOL mode);
 extern char *return_track_tmpname(song_typ *track);
 extern void is_stat(WINDOW *win, int ys, int ye, int x, int abs, int tot);
-extern char config_fancy_colors;
+extern signed char config_fancy_colors;
 extern char *def_mp3_dir;
 extern char *def_mp3_info;
 extern char *def_cd_rip_nf;
@@ -434,7 +434,7 @@ int rip_non_fly(song_typ *track)
 
   /* check for ripper-program */
   if(! str_path_check(def_cd_rip_nf)) {
-    popup_error_win(_("couldnt rip, no prg in $PATH"));
+    popup_error_win(_("couldn't rip, no prg in $PATH"));
     return 1;
   }
   
@@ -576,7 +576,7 @@ int enc_non_fly(song_typ *track, BOOL del_tmp_file)
   }
   
   if(! str_path_check(def_mp3_enc_nf)) {
-    popup_error_win(_("couldnt encode, no prg in $PATH"));
+    popup_error_win(_("couldn't encode, no prg in $PATH"));
     return 1;
   }
  
@@ -714,7 +714,7 @@ int get_fifo(int fd)
 
   bytes = proc_fifo_in - proc_fifo_out;
   if(bytes < 0) bytes = (fifo_size - proc_fifo_out) + proc_fifo_in;
-  sprintf(buf, "FIFO: %3d%% full", (bytes * 100) / fifo_size);
+  sprintf(buf, _("FIFO: %3d%% full"), (bytes * 100) / fifo_size);
   mvwaddnstr(proc_out_win, 0, 1, buf, (fifo_for_maxx)-2);
 
   if(proc_fifo_out > proc_fifo_in) {
